@@ -10,6 +10,23 @@ use File::Find::Rule;
 use Locale::Maketext::Extract;
 use base qw(App::I18N::Command);
 
+=head1 NAME
+
+parse - parse i18n string from files.
+
+=head1 USAGE
+
+parse [options] [path]
+
+=head1 OPTIONS
+
+    --lang
+    --locale
+    --podir=[path]
+    --mo
+
+=cut
+
 sub options {
     (
     'q|quiet'  => 'quiet',
@@ -17,13 +34,11 @@ sub options {
     'locale'   => 'locale',   # XXX: use locale directory structure
     'podir=s'  => 'podir',
     'mo'       => 'mo',
-    'js'       => 'js',
     );
 }
 
 our $LMExtract = App::I18N->lm_extract();
 
-
 sub print_help_message {
     # XXX:
     return;
